# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onshape_client.api_client import ApiClient


class AppElementsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def commit_transaction(self, did, eid, wid, tid, bt_app_element_commit_transaction_params, **kwargs):  # noqa: E501
        """Commit Transaction  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.commit_transaction(did, eid, wid, tid, bt_app_element_commit_transaction_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wid: (required)
        :param str tid: (required)
        :param BTAppElementCommitTransactionParams bt_app_element_commit_transaction_params: (required)
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.commit_transaction_with_http_info(did, eid, wid, tid, bt_app_element_commit_transaction_params, **kwargs)  # noqa: E501
        else:
            (data) = self.commit_transaction_with_http_info(did, eid, wid, tid, bt_app_element_commit_transaction_params, **kwargs)  # noqa: E501
            return data

    def commit_transaction_with_http_info(self, did, eid, wid, tid, bt_app_element_commit_transaction_params, **kwargs):  # noqa: E501
        """Commit Transaction  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.commit_transaction_with_http_info(did, eid, wid, tid, bt_app_element_commit_transaction_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wid: (required)
        :param str tid: (required)
        :param BTAppElementCommitTransactionParams bt_app_element_commit_transaction_params: (required)
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wid', 'tid', 'bt_app_element_commit_transaction_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method commit_transaction" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `commit_transaction`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `commit_transaction`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `commit_transaction`")  # noqa: E501
        # verify the required parameter 'tid' is set
        if ('tid' not in local_var_params or
                local_var_params['tid'] is None):
            raise ValueError("Missing the required parameter `tid` when calling `commit_transaction`")  # noqa: E501
        # verify the required parameter 'bt_app_element_commit_transaction_params' is set
        if ('bt_app_element_commit_transaction_params' not in local_var_params or
                local_var_params['bt_app_element_commit_transaction_params'] is None):
            raise ValueError("Missing the required parameter `bt_app_element_commit_transaction_params` when calling `commit_transaction`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501
        if 'tid' in local_var_params:
            path_params['tid'] = local_var_params['tid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_app_element_commit_transaction_params' in local_var_params:
            body_params = local_var_params['bt_app_element_commit_transaction_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/w/{wid}/e/{eid}/transactions/{tid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementModifyInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create7(self, did, wid, bt_app_element_params, **kwargs):  # noqa: E501
        """Create Element.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create7(did, wid, bt_app_element_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param BTAppElementParams bt_app_element_params: (required)
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create7_with_http_info(did, wid, bt_app_element_params, **kwargs)  # noqa: E501
        else:
            (data) = self.create7_with_http_info(did, wid, bt_app_element_params, **kwargs)  # noqa: E501
            return data

    def create7_with_http_info(self, did, wid, bt_app_element_params, **kwargs):  # noqa: E501
        """Create Element.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create7_with_http_info(did, wid, bt_app_element_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param BTAppElementParams bt_app_element_params: (required)
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'bt_app_element_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create7" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `create7`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `create7`")  # noqa: E501
        # verify the required parameter 'bt_app_element_params' is set
        if ('bt_app_element_params' not in local_var_params or
                local_var_params['bt_app_element_params'] is None):
            raise ValueError("Missing the required parameter `bt_app_element_params` when calling `create7`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_app_element_params' in local_var_params:
            body_params = local_var_params['bt_app_element_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/w/{wid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementModifyInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_reference1(self, did, eid, wvm, wvmid, bt_app_element_reference_params, **kwargs):  # noqa: E501
        """Create Reference  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_reference1(did, eid, wvm, wvmid, bt_app_element_reference_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param BTAppElementReferenceParams bt_app_element_reference_params: (required)
        :return: BTAppElementReferenceInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_reference1_with_http_info(did, eid, wvm, wvmid, bt_app_element_reference_params, **kwargs)  # noqa: E501
        else:
            (data) = self.create_reference1_with_http_info(did, eid, wvm, wvmid, bt_app_element_reference_params, **kwargs)  # noqa: E501
            return data

    def create_reference1_with_http_info(self, did, eid, wvm, wvmid, bt_app_element_reference_params, **kwargs):  # noqa: E501
        """Create Reference  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_reference1_with_http_info(did, eid, wvm, wvmid, bt_app_element_reference_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param BTAppElementReferenceParams bt_app_element_reference_params: (required)
        :return: BTAppElementReferenceInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wvm', 'wvmid', 'bt_app_element_reference_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_reference1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `create_reference1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `create_reference1`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `create_reference1`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `create_reference1`")  # noqa: E501
        # verify the required parameter 'bt_app_element_reference_params' is set
        if ('bt_app_element_reference_params' not in local_var_params or
                local_var_params['bt_app_element_reference_params'] is None):
            raise ValueError("Missing the required parameter `bt_app_element_reference_params` when calling `create_reference1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_app_element_reference_params' in local_var_params:
            body_params = local_var_params['bt_app_element_reference_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/references', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementReferenceInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_content1(self, did, eid, wvm, wvmid, sid, **kwargs):  # noqa: E501
        """Delete a Sub-element  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_content1(did, eid, wvm, wvmid, sid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str sid: (required)
        :param str transaction_id:
        :param str parent_change_id:
        :param str description:
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_content1_with_http_info(did, eid, wvm, wvmid, sid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_content1_with_http_info(did, eid, wvm, wvmid, sid, **kwargs)  # noqa: E501
            return data

    def delete_content1_with_http_info(self, did, eid, wvm, wvmid, sid, **kwargs):  # noqa: E501
        """Delete a Sub-element  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_content1_with_http_info(did, eid, wvm, wvmid, sid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str sid: (required)
        :param str transaction_id:
        :param str parent_change_id:
        :param str description:
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wvm', 'wvmid', 'sid', 'transaction_id', 'parent_change_id', 'description']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_content1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `delete_content1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `delete_content1`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `delete_content1`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `delete_content1`")  # noqa: E501
        # verify the required parameter 'sid' is set
        if ('sid' not in local_var_params or
                local_var_params['sid'] is None):
            raise ValueError("Missing the required parameter `sid` when calling `delete_content1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'sid' in local_var_params:
            path_params['sid'] = local_var_params['sid']  # noqa: E501

        query_params = []
        if 'transaction_id' in local_var_params:
            query_params.append(('transactionId', local_var_params['transaction_id']))  # noqa: E501
        if 'parent_change_id' in local_var_params:
            query_params.append(('parentChangeId', local_var_params['parent_change_id']))  # noqa: E501
        if 'description' in local_var_params:
            query_params.append(('description', local_var_params['description']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/content/subelements/{sid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementModifyInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_reference1(self, did, eid, wvm, wvmid, rid, **kwargs):  # noqa: E501
        """Delete Reference  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_reference1(did, eid, wvm, wvmid, rid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str rid: (required)
        :param str transaction_id:
        :param str parent_change_id:
        :param str description:
        :return: BTAppElementReferenceInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_reference1_with_http_info(did, eid, wvm, wvmid, rid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_reference1_with_http_info(did, eid, wvm, wvmid, rid, **kwargs)  # noqa: E501
            return data

    def delete_reference1_with_http_info(self, did, eid, wvm, wvmid, rid, **kwargs):  # noqa: E501
        """Delete Reference  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_reference1_with_http_info(did, eid, wvm, wvmid, rid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str rid: (required)
        :param str transaction_id:
        :param str parent_change_id:
        :param str description:
        :return: BTAppElementReferenceInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wvm', 'wvmid', 'rid', 'transaction_id', 'parent_change_id', 'description']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_reference1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `delete_reference1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `delete_reference1`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `delete_reference1`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `delete_reference1`")  # noqa: E501
        # verify the required parameter 'rid' is set
        if ('rid' not in local_var_params or
                local_var_params['rid'] is None):
            raise ValueError("Missing the required parameter `rid` when calling `delete_reference1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'rid' in local_var_params:
            path_params['rid'] = local_var_params['rid']  # noqa: E501

        query_params = []
        if 'transaction_id' in local_var_params:
            query_params.append(('transactionId', local_var_params['transaction_id']))  # noqa: E501
        if 'parent_change_id' in local_var_params:
            query_params.append(('parentChangeId', local_var_params['parent_change_id']))  # noqa: E501
        if 'description' in local_var_params:
            query_params.append(('description', local_var_params['description']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/references/{rid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementReferenceInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_history(self, did, eid, wvm, wvmid, **kwargs):  # noqa: E501
        """Get History  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_history(did, eid, wvm, wvmid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :return: BTAppElementHistoryInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_history_with_http_info(did, eid, wvm, wvmid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_history_with_http_info(did, eid, wvm, wvmid, **kwargs)  # noqa: E501
            return data

    def get_history_with_http_info(self, did, eid, wvm, wvmid, **kwargs):  # noqa: E501
        """Get History  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_history_with_http_info(did, eid, wvm, wvmid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :return: BTAppElementHistoryInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wvm', 'wvmid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_history" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_history`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_history`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_history`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_history`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/content/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementHistoryInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sub_element_content(self, did, eid, wvm, wvmid, **kwargs):  # noqa: E501
        """Get Content  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sub_element_content(did, eid, wvm, wvmid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str transaction_id:
        :param str change_id:
        :param str base_change_id:
        :param str subelement_id:
        :param str link_document_id:
        :return: BTAppElementContentInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sub_element_content_with_http_info(did, eid, wvm, wvmid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sub_element_content_with_http_info(did, eid, wvm, wvmid, **kwargs)  # noqa: E501
            return data

    def get_sub_element_content_with_http_info(self, did, eid, wvm, wvmid, **kwargs):  # noqa: E501
        """Get Content  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sub_element_content_with_http_info(did, eid, wvm, wvmid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str transaction_id:
        :param str change_id:
        :param str base_change_id:
        :param str subelement_id:
        :param str link_document_id:
        :return: BTAppElementContentInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wvm', 'wvmid', 'transaction_id', 'change_id', 'base_change_id', 'subelement_id', 'link_document_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sub_element_content" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_sub_element_content`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_sub_element_content`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_sub_element_content`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_sub_element_content`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501

        query_params = []
        if 'transaction_id' in local_var_params:
            query_params.append(('transactionId', local_var_params['transaction_id']))  # noqa: E501
        if 'change_id' in local_var_params:
            query_params.append(('changeId', local_var_params['change_id']))  # noqa: E501
        if 'base_change_id' in local_var_params:
            query_params.append(('baseChangeId', local_var_params['base_change_id']))  # noqa: E501
        if 'subelement_id' in local_var_params:
            query_params.append(('subelementId', local_var_params['subelement_id']))  # noqa: E501
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/content', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementContentInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_subelement_ids(self, did, eid, wvm, wvmid, **kwargs):  # noqa: E501
        """Get Sub-element IDs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_subelement_ids(did, eid, wvm, wvmid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str transaction_id:
        :param str change_id:
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_subelement_ids_with_http_info(did, eid, wvm, wvmid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_subelement_ids_with_http_info(did, eid, wvm, wvmid, **kwargs)  # noqa: E501
            return data

    def get_subelement_ids_with_http_info(self, did, eid, wvm, wvmid, **kwargs):  # noqa: E501
        """Get Sub-element IDs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_subelement_ids_with_http_info(did, eid, wvm, wvmid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str transaction_id:
        :param str change_id:
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wvm', 'wvmid', 'transaction_id', 'change_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_subelement_ids" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_subelement_ids`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_subelement_ids`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_subelement_ids`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_subelement_ids`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501

        query_params = []
        if 'transaction_id' in local_var_params:
            query_params.append(('transactionId', local_var_params['transaction_id']))  # noqa: E501
        if 'change_id' in local_var_params:
            query_params.append(('changeId', local_var_params['change_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/content/ids', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementModifyInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resolve_reference1(self, did, eid, wvm, wvmid, rid, **kwargs):  # noqa: E501
        """Resolve Reference  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resolve_reference1(did, eid, wvm, wvmid, rid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str rid: (required)
        :param str transaction_id:
        :param str parent_change_id:
        :param bool include_internal:
        :param str link_document_id:
        :return: BTAppElementReferenceResolveInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.resolve_reference1_with_http_info(did, eid, wvm, wvmid, rid, **kwargs)  # noqa: E501
        else:
            (data) = self.resolve_reference1_with_http_info(did, eid, wvm, wvmid, rid, **kwargs)  # noqa: E501
            return data

    def resolve_reference1_with_http_info(self, did, eid, wvm, wvmid, rid, **kwargs):  # noqa: E501
        """Resolve Reference  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resolve_reference1_with_http_info(did, eid, wvm, wvmid, rid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str rid: (required)
        :param str transaction_id:
        :param str parent_change_id:
        :param bool include_internal:
        :param str link_document_id:
        :return: BTAppElementReferenceResolveInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wvm', 'wvmid', 'rid', 'transaction_id', 'parent_change_id', 'include_internal', 'link_document_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resolve_reference1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `resolve_reference1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `resolve_reference1`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `resolve_reference1`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `resolve_reference1`")  # noqa: E501
        # verify the required parameter 'rid' is set
        if ('rid' not in local_var_params or
                local_var_params['rid'] is None):
            raise ValueError("Missing the required parameter `rid` when calling `resolve_reference1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'rid' in local_var_params:
            path_params['rid'] = local_var_params['rid']  # noqa: E501

        query_params = []
        if 'transaction_id' in local_var_params:
            query_params.append(('transactionId', local_var_params['transaction_id']))  # noqa: E501
        if 'parent_change_id' in local_var_params:
            query_params.append(('parentChangeId', local_var_params['parent_change_id']))  # noqa: E501
        if 'include_internal' in local_var_params:
            query_params.append(('includeInternal', local_var_params['include_internal']))  # noqa: E501
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/references/{rid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementReferenceResolveInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_transaction(self, did, eid, wid, bt_app_element_start_transaction_params, **kwargs):  # noqa: E501
        """Start Transaction  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_transaction(did, eid, wid, bt_app_element_start_transaction_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wid: (required)
        :param BTAppElementStartTransactionParams bt_app_element_start_transaction_params: (required)
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.start_transaction_with_http_info(did, eid, wid, bt_app_element_start_transaction_params, **kwargs)  # noqa: E501
        else:
            (data) = self.start_transaction_with_http_info(did, eid, wid, bt_app_element_start_transaction_params, **kwargs)  # noqa: E501
            return data

    def start_transaction_with_http_info(self, did, eid, wid, bt_app_element_start_transaction_params, **kwargs):  # noqa: E501
        """Start Transaction  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_transaction_with_http_info(did, eid, wid, bt_app_element_start_transaction_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wid: (required)
        :param BTAppElementStartTransactionParams bt_app_element_start_transaction_params: (required)
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wid', 'bt_app_element_start_transaction_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_transaction" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `start_transaction`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `start_transaction`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `start_transaction`")  # noqa: E501
        # verify the required parameter 'bt_app_element_start_transaction_params' is set
        if ('bt_app_element_start_transaction_params' not in local_var_params or
                local_var_params['bt_app_element_start_transaction_params'] is None):
            raise ValueError("Missing the required parameter `bt_app_element_start_transaction_params` when calling `start_transaction`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_app_element_start_transaction_params' in local_var_params:
            body_params = local_var_params['bt_app_element_start_transaction_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/w/{wid}/e/{eid}/transactions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementModifyInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update5(self, did, eid, wvm, wvmid, bt_app_element_update_params, **kwargs):  # noqa: E501
        """Update Element  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update5(did, eid, wvm, wvmid, bt_app_element_update_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param BTAppElementUpdateParams bt_app_element_update_params: (required)
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update5_with_http_info(did, eid, wvm, wvmid, bt_app_element_update_params, **kwargs)  # noqa: E501
        else:
            (data) = self.update5_with_http_info(did, eid, wvm, wvmid, bt_app_element_update_params, **kwargs)  # noqa: E501
            return data

    def update5_with_http_info(self, did, eid, wvm, wvmid, bt_app_element_update_params, **kwargs):  # noqa: E501
        """Update Element  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update5_with_http_info(did, eid, wvm, wvmid, bt_app_element_update_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param BTAppElementUpdateParams bt_app_element_update_params: (required)
        :return: BTAppElementModifyInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wvm', 'wvmid', 'bt_app_element_update_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update5" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `update5`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `update5`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `update5`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `update5`")  # noqa: E501
        # verify the required parameter 'bt_app_element_update_params' is set
        if ('bt_app_element_update_params' not in local_var_params or
                local_var_params['bt_app_element_update_params'] is None):
            raise ValueError("Missing the required parameter `bt_app_element_update_params` when calling `update5`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_app_element_update_params' in local_var_params:
            body_params = local_var_params['bt_app_element_update_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/content', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementModifyInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_reference1(self, did, eid, wvm, wvmid, rid, bt_app_element_reference_params, **kwargs):  # noqa: E501
        """Update Reference  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_reference1(did, eid, wvm, wvmid, rid, bt_app_element_reference_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str rid: (required)
        :param BTAppElementReferenceParams bt_app_element_reference_params: (required)
        :return: BTAppElementReferenceInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_reference1_with_http_info(did, eid, wvm, wvmid, rid, bt_app_element_reference_params, **kwargs)  # noqa: E501
        else:
            (data) = self.update_reference1_with_http_info(did, eid, wvm, wvmid, rid, bt_app_element_reference_params, **kwargs)  # noqa: E501
            return data

    def update_reference1_with_http_info(self, did, eid, wvm, wvmid, rid, bt_app_element_reference_params, **kwargs):  # noqa: E501
        """Update Reference  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_reference1_with_http_info(did, eid, wvm, wvmid, rid, bt_app_element_reference_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str rid: (required)
        :param BTAppElementReferenceParams bt_app_element_reference_params: (required)
        :return: BTAppElementReferenceInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'wvm', 'wvmid', 'rid', 'bt_app_element_reference_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_reference1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `update_reference1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `update_reference1`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `update_reference1`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `update_reference1`")  # noqa: E501
        # verify the required parameter 'rid' is set
        if ('rid' not in local_var_params or
                local_var_params['rid'] is None):
            raise ValueError("Missing the required parameter `rid` when calling `update_reference1`")  # noqa: E501
        # verify the required parameter 'bt_app_element_reference_params' is set
        if ('bt_app_element_reference_params' not in local_var_params or
                local_var_params['bt_app_element_reference_params'] is None):
            raise ValueError("Missing the required parameter `bt_app_element_reference_params` when calling `update_reference1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'rid' in local_var_params:
            path_params['rid'] = local_var_params['rid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_app_element_reference_params' in local_var_params:
            body_params = local_var_params['bt_app_element_reference_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/appelements/d/{did}/{wvm}/{wvmid}/e/{eid}/references/{rid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTAppElementReferenceInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Customer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'object': 'str',
        'account_balance': 'int',
        'business_vat_id': 'str',
        'created': 'int',
        'currency': 'str',
        'default_source': 'str',
        'deleted': 'bool',
        'delinquent': 'bool',
        'description': 'str',
        'discount': 'Discount',
        'email': 'str',
        'livemode': 'bool',
        'metadata': 'dict(str, str)',
        'shipping': 'ShippingDetails',
        'sources': 'ExternalAccountCollection',
        'subscriptions': 'CustomerSubscriptionCollection',
        'cards': 'CustomerCardCollection',
        'default_card': 'str',
        'next_recurring_charge': 'NextRecurringCharge',
        'subscription': 'Subscription',
        'trial_end': 'int',
        'default_source_object': 'ExternalAccount'
    }

    attribute_map = {
        'id': 'id',
        'object': 'object',
        'account_balance': 'accountBalance',
        'business_vat_id': 'businessVatId',
        'created': 'created',
        'currency': 'currency',
        'default_source': 'defaultSource',
        'deleted': 'deleted',
        'delinquent': 'delinquent',
        'description': 'description',
        'discount': 'discount',
        'email': 'email',
        'livemode': 'livemode',
        'metadata': 'metadata',
        'shipping': 'shipping',
        'sources': 'sources',
        'subscriptions': 'subscriptions',
        'cards': 'cards',
        'default_card': 'defaultCard',
        'next_recurring_charge': 'nextRecurringCharge',
        'subscription': 'subscription',
        'trial_end': 'trialEnd',
        'default_source_object': 'defaultSourceObject'
    }

    def __init__(self, id=None, object=None, account_balance=None, business_vat_id=None, created=None, currency=None, default_source=None, deleted=None, delinquent=None, description=None, discount=None, email=None, livemode=None, metadata=None, shipping=None, sources=None, subscriptions=None, cards=None, default_card=None, next_recurring_charge=None, subscription=None, trial_end=None, default_source_object=None):  # noqa: E501
        """Customer - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._object = None
        self._account_balance = None
        self._business_vat_id = None
        self._created = None
        self._currency = None
        self._default_source = None
        self._deleted = None
        self._delinquent = None
        self._description = None
        self._discount = None
        self._email = None
        self._livemode = None
        self._metadata = None
        self._shipping = None
        self._sources = None
        self._subscriptions = None
        self._cards = None
        self._default_card = None
        self._next_recurring_charge = None
        self._subscription = None
        self._trial_end = None
        self._default_source_object = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if object is not None:
            self.object = object
        if account_balance is not None:
            self.account_balance = account_balance
        if business_vat_id is not None:
            self.business_vat_id = business_vat_id
        if created is not None:
            self.created = created
        if currency is not None:
            self.currency = currency
        if default_source is not None:
            self.default_source = default_source
        if deleted is not None:
            self.deleted = deleted
        if delinquent is not None:
            self.delinquent = delinquent
        if description is not None:
            self.description = description
        if discount is not None:
            self.discount = discount
        if email is not None:
            self.email = email
        if livemode is not None:
            self.livemode = livemode
        if metadata is not None:
            self.metadata = metadata
        if shipping is not None:
            self.shipping = shipping
        if sources is not None:
            self.sources = sources
        if subscriptions is not None:
            self.subscriptions = subscriptions
        if cards is not None:
            self.cards = cards
        if default_card is not None:
            self.default_card = default_card
        if next_recurring_charge is not None:
            self.next_recurring_charge = next_recurring_charge
        if subscription is not None:
            self.subscription = subscription
        if trial_end is not None:
            self.trial_end = trial_end
        if default_source_object is not None:
            self.default_source_object = default_source_object

    @property
    def id(self):
        """Gets the id of this Customer.  # noqa: E501


        :return: The id of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Customer.


        :param id: The id of this Customer.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def object(self):
        """Gets the object of this Customer.  # noqa: E501


        :return: The object of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this Customer.


        :param object: The object of this Customer.  # noqa: E501
        :type: str
        """

        self._object = object

    @property
    def account_balance(self):
        """Gets the account_balance of this Customer.  # noqa: E501


        :return: The account_balance of this Customer.  # noqa: E501
        :rtype: int
        """
        return self._account_balance

    @account_balance.setter
    def account_balance(self, account_balance):
        """Sets the account_balance of this Customer.


        :param account_balance: The account_balance of this Customer.  # noqa: E501
        :type: int
        """

        self._account_balance = account_balance

    @property
    def business_vat_id(self):
        """Gets the business_vat_id of this Customer.  # noqa: E501


        :return: The business_vat_id of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._business_vat_id

    @business_vat_id.setter
    def business_vat_id(self, business_vat_id):
        """Sets the business_vat_id of this Customer.


        :param business_vat_id: The business_vat_id of this Customer.  # noqa: E501
        :type: str
        """

        self._business_vat_id = business_vat_id

    @property
    def created(self):
        """Gets the created of this Customer.  # noqa: E501


        :return: The created of this Customer.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Customer.


        :param created: The created of this Customer.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def currency(self):
        """Gets the currency of this Customer.  # noqa: E501


        :return: The currency of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Customer.


        :param currency: The currency of this Customer.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def default_source(self):
        """Gets the default_source of this Customer.  # noqa: E501


        :return: The default_source of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._default_source

    @default_source.setter
    def default_source(self, default_source):
        """Sets the default_source of this Customer.


        :param default_source: The default_source of this Customer.  # noqa: E501
        :type: str
        """

        self._default_source = default_source

    @property
    def deleted(self):
        """Gets the deleted of this Customer.  # noqa: E501


        :return: The deleted of this Customer.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this Customer.


        :param deleted: The deleted of this Customer.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def delinquent(self):
        """Gets the delinquent of this Customer.  # noqa: E501


        :return: The delinquent of this Customer.  # noqa: E501
        :rtype: bool
        """
        return self._delinquent

    @delinquent.setter
    def delinquent(self, delinquent):
        """Sets the delinquent of this Customer.


        :param delinquent: The delinquent of this Customer.  # noqa: E501
        :type: bool
        """

        self._delinquent = delinquent

    @property
    def description(self):
        """Gets the description of this Customer.  # noqa: E501


        :return: The description of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Customer.


        :param description: The description of this Customer.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def discount(self):
        """Gets the discount of this Customer.  # noqa: E501


        :return: The discount of this Customer.  # noqa: E501
        :rtype: Discount
        """
        return self._discount

    @discount.setter
    def discount(self, discount):
        """Sets the discount of this Customer.


        :param discount: The discount of this Customer.  # noqa: E501
        :type: Discount
        """

        self._discount = discount

    @property
    def email(self):
        """Gets the email of this Customer.  # noqa: E501


        :return: The email of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Customer.


        :param email: The email of this Customer.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def livemode(self):
        """Gets the livemode of this Customer.  # noqa: E501


        :return: The livemode of this Customer.  # noqa: E501
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """Sets the livemode of this Customer.


        :param livemode: The livemode of this Customer.  # noqa: E501
        :type: bool
        """

        self._livemode = livemode

    @property
    def metadata(self):
        """Gets the metadata of this Customer.  # noqa: E501


        :return: The metadata of this Customer.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this Customer.


        :param metadata: The metadata of this Customer.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def shipping(self):
        """Gets the shipping of this Customer.  # noqa: E501


        :return: The shipping of this Customer.  # noqa: E501
        :rtype: ShippingDetails
        """
        return self._shipping

    @shipping.setter
    def shipping(self, shipping):
        """Sets the shipping of this Customer.


        :param shipping: The shipping of this Customer.  # noqa: E501
        :type: ShippingDetails
        """

        self._shipping = shipping

    @property
    def sources(self):
        """Gets the sources of this Customer.  # noqa: E501


        :return: The sources of this Customer.  # noqa: E501
        :rtype: ExternalAccountCollection
        """
        return self._sources

    @sources.setter
    def sources(self, sources):
        """Sets the sources of this Customer.


        :param sources: The sources of this Customer.  # noqa: E501
        :type: ExternalAccountCollection
        """

        self._sources = sources

    @property
    def subscriptions(self):
        """Gets the subscriptions of this Customer.  # noqa: E501


        :return: The subscriptions of this Customer.  # noqa: E501
        :rtype: CustomerSubscriptionCollection
        """
        return self._subscriptions

    @subscriptions.setter
    def subscriptions(self, subscriptions):
        """Sets the subscriptions of this Customer.


        :param subscriptions: The subscriptions of this Customer.  # noqa: E501
        :type: CustomerSubscriptionCollection
        """

        self._subscriptions = subscriptions

    @property
    def cards(self):
        """Gets the cards of this Customer.  # noqa: E501


        :return: The cards of this Customer.  # noqa: E501
        :rtype: CustomerCardCollection
        """
        return self._cards

    @cards.setter
    def cards(self, cards):
        """Sets the cards of this Customer.


        :param cards: The cards of this Customer.  # noqa: E501
        :type: CustomerCardCollection
        """

        self._cards = cards

    @property
    def default_card(self):
        """Gets the default_card of this Customer.  # noqa: E501


        :return: The default_card of this Customer.  # noqa: E501
        :rtype: str
        """
        return self._default_card

    @default_card.setter
    def default_card(self, default_card):
        """Sets the default_card of this Customer.


        :param default_card: The default_card of this Customer.  # noqa: E501
        :type: str
        """

        self._default_card = default_card

    @property
    def next_recurring_charge(self):
        """Gets the next_recurring_charge of this Customer.  # noqa: E501


        :return: The next_recurring_charge of this Customer.  # noqa: E501
        :rtype: NextRecurringCharge
        """
        return self._next_recurring_charge

    @next_recurring_charge.setter
    def next_recurring_charge(self, next_recurring_charge):
        """Sets the next_recurring_charge of this Customer.


        :param next_recurring_charge: The next_recurring_charge of this Customer.  # noqa: E501
        :type: NextRecurringCharge
        """

        self._next_recurring_charge = next_recurring_charge

    @property
    def subscription(self):
        """Gets the subscription of this Customer.  # noqa: E501


        :return: The subscription of this Customer.  # noqa: E501
        :rtype: Subscription
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this Customer.


        :param subscription: The subscription of this Customer.  # noqa: E501
        :type: Subscription
        """

        self._subscription = subscription

    @property
    def trial_end(self):
        """Gets the trial_end of this Customer.  # noqa: E501


        :return: The trial_end of this Customer.  # noqa: E501
        :rtype: int
        """
        return self._trial_end

    @trial_end.setter
    def trial_end(self, trial_end):
        """Sets the trial_end of this Customer.


        :param trial_end: The trial_end of this Customer.  # noqa: E501
        :type: int
        """

        self._trial_end = trial_end

    @property
    def default_source_object(self):
        """Gets the default_source_object of this Customer.  # noqa: E501


        :return: The default_source_object of this Customer.  # noqa: E501
        :rtype: ExternalAccount
        """
        return self._default_source_object

    @default_source_object.setter
    def default_source_object(self, default_source_object):
        """Sets the default_source_object of this Customer.


        :param default_source_object: The default_source_object of this Customer.  # noqa: E501
        :type: ExternalAccount
        """

        self._default_source_object = default_source_object

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Customer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTStandardContentHierarchy(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'standard': 'str',
        'category': 'str',
        'types': 'str',
        'type': 'str',
        'document_type': 'int',
        'production_version_id': 'str',
        'test_version_id': 'str',
        'created_at': 'datetime',
        'modified_at': 'datetime',
        'created_by': 'str',
        'modified_by': 'str',
        'document_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'standard': 'standard',
        'category': 'category',
        'types': 'types',
        'type': 'type',
        'document_type': 'documentType',
        'production_version_id': 'productionVersionId',
        'test_version_id': 'testVersionId',
        'created_at': 'createdAt',
        'modified_at': 'modifiedAt',
        'created_by': 'createdBy',
        'modified_by': 'modifiedBy',
        'document_id': 'documentId'
    }

    def __init__(self, id=None, standard=None, category=None, types=None, type=None, document_type=None, production_version_id=None, test_version_id=None, created_at=None, modified_at=None, created_by=None, modified_by=None, document_id=None):  # noqa: E501
        """BTStandardContentHierarchy - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._standard = None
        self._category = None
        self._types = None
        self._type = None
        self._document_type = None
        self._production_version_id = None
        self._test_version_id = None
        self._created_at = None
        self._modified_at = None
        self._created_by = None
        self._modified_by = None
        self._document_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if standard is not None:
            self.standard = standard
        if category is not None:
            self.category = category
        if types is not None:
            self.types = types
        if type is not None:
            self.type = type
        if document_type is not None:
            self.document_type = document_type
        if production_version_id is not None:
            self.production_version_id = production_version_id
        if test_version_id is not None:
            self.test_version_id = test_version_id
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        if document_id is not None:
            self.document_id = document_id

    @property
    def id(self):
        """Gets the id of this BTStandardContentHierarchy.  # noqa: E501


        :return: The id of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTStandardContentHierarchy.


        :param id: The id of this BTStandardContentHierarchy.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def standard(self):
        """Gets the standard of this BTStandardContentHierarchy.  # noqa: E501


        :return: The standard of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._standard

    @standard.setter
    def standard(self, standard):
        """Sets the standard of this BTStandardContentHierarchy.


        :param standard: The standard of this BTStandardContentHierarchy.  # noqa: E501
        :type: str
        """

        self._standard = standard

    @property
    def category(self):
        """Gets the category of this BTStandardContentHierarchy.  # noqa: E501


        :return: The category of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this BTStandardContentHierarchy.


        :param category: The category of this BTStandardContentHierarchy.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def types(self):
        """Gets the types of this BTStandardContentHierarchy.  # noqa: E501


        :return: The types of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._types

    @types.setter
    def types(self, types):
        """Sets the types of this BTStandardContentHierarchy.


        :param types: The types of this BTStandardContentHierarchy.  # noqa: E501
        :type: str
        """

        self._types = types

    @property
    def type(self):
        """Gets the type of this BTStandardContentHierarchy.  # noqa: E501


        :return: The type of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTStandardContentHierarchy.


        :param type: The type of this BTStandardContentHierarchy.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def document_type(self):
        """Gets the document_type of this BTStandardContentHierarchy.  # noqa: E501


        :return: The document_type of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: int
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """Sets the document_type of this BTStandardContentHierarchy.


        :param document_type: The document_type of this BTStandardContentHierarchy.  # noqa: E501
        :type: int
        """

        self._document_type = document_type

    @property
    def production_version_id(self):
        """Gets the production_version_id of this BTStandardContentHierarchy.  # noqa: E501


        :return: The production_version_id of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._production_version_id

    @production_version_id.setter
    def production_version_id(self, production_version_id):
        """Sets the production_version_id of this BTStandardContentHierarchy.


        :param production_version_id: The production_version_id of this BTStandardContentHierarchy.  # noqa: E501
        :type: str
        """

        self._production_version_id = production_version_id

    @property
    def test_version_id(self):
        """Gets the test_version_id of this BTStandardContentHierarchy.  # noqa: E501


        :return: The test_version_id of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._test_version_id

    @test_version_id.setter
    def test_version_id(self, test_version_id):
        """Sets the test_version_id of this BTStandardContentHierarchy.


        :param test_version_id: The test_version_id of this BTStandardContentHierarchy.  # noqa: E501
        :type: str
        """

        self._test_version_id = test_version_id

    @property
    def created_at(self):
        """Gets the created_at of this BTStandardContentHierarchy.  # noqa: E501


        :return: The created_at of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BTStandardContentHierarchy.


        :param created_at: The created_at of this BTStandardContentHierarchy.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this BTStandardContentHierarchy.  # noqa: E501


        :return: The modified_at of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this BTStandardContentHierarchy.


        :param modified_at: The modified_at of this BTStandardContentHierarchy.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def created_by(self):
        """Gets the created_by of this BTStandardContentHierarchy.  # noqa: E501


        :return: The created_by of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this BTStandardContentHierarchy.


        :param created_by: The created_by of this BTStandardContentHierarchy.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this BTStandardContentHierarchy.  # noqa: E501


        :return: The modified_by of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this BTStandardContentHierarchy.


        :param modified_by: The modified_by of this BTStandardContentHierarchy.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def document_id(self):
        """Gets the document_id of this BTStandardContentHierarchy.  # noqa: E501


        :return: The document_id of this BTStandardContentHierarchy.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTStandardContentHierarchy.


        :param document_id: The document_id of this BTStandardContentHierarchy.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTStandardContentHierarchy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTModelTessellationParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'configuration': 'str',
        'workspace_id': 'str',
        'element_id': 'str',
        'part_ids': 'list[str]',
        'part_query': 'str',
        'angle_tolerance': 'float',
        'chord_tolerance': 'float',
        'max_facet_width': 'float',
        'output_vertex_normals': 'bool',
        'output_facet_normals': 'bool',
        'output_texture_coordinates': 'bool',
        'output_index_table': 'bool',
        'entity_ids': 'list[str]',
        'output_error_faces': 'bool',
        'part_id': 'str',
        'document_id': 'str',
        'element_microversion_id': 'str'
    }

    attribute_map = {
        'configuration': 'configuration',
        'workspace_id': 'workspaceId',
        'element_id': 'elementId',
        'part_ids': 'partIds',
        'part_query': 'partQuery',
        'angle_tolerance': 'angleTolerance',
        'chord_tolerance': 'chordTolerance',
        'max_facet_width': 'maxFacetWidth',
        'output_vertex_normals': 'outputVertexNormals',
        'output_facet_normals': 'outputFacetNormals',
        'output_texture_coordinates': 'outputTextureCoordinates',
        'output_index_table': 'outputIndexTable',
        'entity_ids': 'entityIds',
        'output_error_faces': 'outputErrorFaces',
        'part_id': 'partId',
        'document_id': 'documentId',
        'element_microversion_id': 'elementMicroversionId'
    }

    def __init__(self, configuration=None, workspace_id=None, element_id=None, part_ids=None, part_query=None, angle_tolerance=None, chord_tolerance=None, max_facet_width=None, output_vertex_normals=None, output_facet_normals=None, output_texture_coordinates=None, output_index_table=None, entity_ids=None, output_error_faces=None, part_id=None, document_id=None, element_microversion_id=None):  # noqa: E501
        """BTModelTessellationParams - a model defined in OpenAPI"""  # noqa: E501

        self._configuration = None
        self._workspace_id = None
        self._element_id = None
        self._part_ids = None
        self._part_query = None
        self._angle_tolerance = None
        self._chord_tolerance = None
        self._max_facet_width = None
        self._output_vertex_normals = None
        self._output_facet_normals = None
        self._output_texture_coordinates = None
        self._output_index_table = None
        self._entity_ids = None
        self._output_error_faces = None
        self._part_id = None
        self._document_id = None
        self._element_microversion_id = None
        self.discriminator = None

        if configuration is not None:
            self.configuration = configuration
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if element_id is not None:
            self.element_id = element_id
        if part_ids is not None:
            self.part_ids = part_ids
        if part_query is not None:
            self.part_query = part_query
        if angle_tolerance is not None:
            self.angle_tolerance = angle_tolerance
        if chord_tolerance is not None:
            self.chord_tolerance = chord_tolerance
        if max_facet_width is not None:
            self.max_facet_width = max_facet_width
        if output_vertex_normals is not None:
            self.output_vertex_normals = output_vertex_normals
        if output_facet_normals is not None:
            self.output_facet_normals = output_facet_normals
        if output_texture_coordinates is not None:
            self.output_texture_coordinates = output_texture_coordinates
        if output_index_table is not None:
            self.output_index_table = output_index_table
        if entity_ids is not None:
            self.entity_ids = entity_ids
        if output_error_faces is not None:
            self.output_error_faces = output_error_faces
        if part_id is not None:
            self.part_id = part_id
        if document_id is not None:
            self.document_id = document_id
        if element_microversion_id is not None:
            self.element_microversion_id = element_microversion_id

    @property
    def configuration(self):
        """Gets the configuration of this BTModelTessellationParams.  # noqa: E501


        :return: The configuration of this BTModelTessellationParams.  # noqa: E501
        :rtype: str
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this BTModelTessellationParams.


        :param configuration: The configuration of this BTModelTessellationParams.  # noqa: E501
        :type: str
        """

        self._configuration = configuration

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTModelTessellationParams.  # noqa: E501


        :return: The workspace_id of this BTModelTessellationParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTModelTessellationParams.


        :param workspace_id: The workspace_id of this BTModelTessellationParams.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def element_id(self):
        """Gets the element_id of this BTModelTessellationParams.  # noqa: E501


        :return: The element_id of this BTModelTessellationParams.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTModelTessellationParams.


        :param element_id: The element_id of this BTModelTessellationParams.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def part_ids(self):
        """Gets the part_ids of this BTModelTessellationParams.  # noqa: E501


        :return: The part_ids of this BTModelTessellationParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._part_ids

    @part_ids.setter
    def part_ids(self, part_ids):
        """Sets the part_ids of this BTModelTessellationParams.


        :param part_ids: The part_ids of this BTModelTessellationParams.  # noqa: E501
        :type: list[str]
        """

        self._part_ids = part_ids

    @property
    def part_query(self):
        """Gets the part_query of this BTModelTessellationParams.  # noqa: E501


        :return: The part_query of this BTModelTessellationParams.  # noqa: E501
        :rtype: str
        """
        return self._part_query

    @part_query.setter
    def part_query(self, part_query):
        """Sets the part_query of this BTModelTessellationParams.


        :param part_query: The part_query of this BTModelTessellationParams.  # noqa: E501
        :type: str
        """

        self._part_query = part_query

    @property
    def angle_tolerance(self):
        """Gets the angle_tolerance of this BTModelTessellationParams.  # noqa: E501


        :return: The angle_tolerance of this BTModelTessellationParams.  # noqa: E501
        :rtype: float
        """
        return self._angle_tolerance

    @angle_tolerance.setter
    def angle_tolerance(self, angle_tolerance):
        """Sets the angle_tolerance of this BTModelTessellationParams.


        :param angle_tolerance: The angle_tolerance of this BTModelTessellationParams.  # noqa: E501
        :type: float
        """

        self._angle_tolerance = angle_tolerance

    @property
    def chord_tolerance(self):
        """Gets the chord_tolerance of this BTModelTessellationParams.  # noqa: E501


        :return: The chord_tolerance of this BTModelTessellationParams.  # noqa: E501
        :rtype: float
        """
        return self._chord_tolerance

    @chord_tolerance.setter
    def chord_tolerance(self, chord_tolerance):
        """Sets the chord_tolerance of this BTModelTessellationParams.


        :param chord_tolerance: The chord_tolerance of this BTModelTessellationParams.  # noqa: E501
        :type: float
        """

        self._chord_tolerance = chord_tolerance

    @property
    def max_facet_width(self):
        """Gets the max_facet_width of this BTModelTessellationParams.  # noqa: E501


        :return: The max_facet_width of this BTModelTessellationParams.  # noqa: E501
        :rtype: float
        """
        return self._max_facet_width

    @max_facet_width.setter
    def max_facet_width(self, max_facet_width):
        """Sets the max_facet_width of this BTModelTessellationParams.


        :param max_facet_width: The max_facet_width of this BTModelTessellationParams.  # noqa: E501
        :type: float
        """

        self._max_facet_width = max_facet_width

    @property
    def output_vertex_normals(self):
        """Gets the output_vertex_normals of this BTModelTessellationParams.  # noqa: E501


        :return: The output_vertex_normals of this BTModelTessellationParams.  # noqa: E501
        :rtype: bool
        """
        return self._output_vertex_normals

    @output_vertex_normals.setter
    def output_vertex_normals(self, output_vertex_normals):
        """Sets the output_vertex_normals of this BTModelTessellationParams.


        :param output_vertex_normals: The output_vertex_normals of this BTModelTessellationParams.  # noqa: E501
        :type: bool
        """

        self._output_vertex_normals = output_vertex_normals

    @property
    def output_facet_normals(self):
        """Gets the output_facet_normals of this BTModelTessellationParams.  # noqa: E501


        :return: The output_facet_normals of this BTModelTessellationParams.  # noqa: E501
        :rtype: bool
        """
        return self._output_facet_normals

    @output_facet_normals.setter
    def output_facet_normals(self, output_facet_normals):
        """Sets the output_facet_normals of this BTModelTessellationParams.


        :param output_facet_normals: The output_facet_normals of this BTModelTessellationParams.  # noqa: E501
        :type: bool
        """

        self._output_facet_normals = output_facet_normals

    @property
    def output_texture_coordinates(self):
        """Gets the output_texture_coordinates of this BTModelTessellationParams.  # noqa: E501


        :return: The output_texture_coordinates of this BTModelTessellationParams.  # noqa: E501
        :rtype: bool
        """
        return self._output_texture_coordinates

    @output_texture_coordinates.setter
    def output_texture_coordinates(self, output_texture_coordinates):
        """Sets the output_texture_coordinates of this BTModelTessellationParams.


        :param output_texture_coordinates: The output_texture_coordinates of this BTModelTessellationParams.  # noqa: E501
        :type: bool
        """

        self._output_texture_coordinates = output_texture_coordinates

    @property
    def output_index_table(self):
        """Gets the output_index_table of this BTModelTessellationParams.  # noqa: E501


        :return: The output_index_table of this BTModelTessellationParams.  # noqa: E501
        :rtype: bool
        """
        return self._output_index_table

    @output_index_table.setter
    def output_index_table(self, output_index_table):
        """Sets the output_index_table of this BTModelTessellationParams.


        :param output_index_table: The output_index_table of this BTModelTessellationParams.  # noqa: E501
        :type: bool
        """

        self._output_index_table = output_index_table

    @property
    def entity_ids(self):
        """Gets the entity_ids of this BTModelTessellationParams.  # noqa: E501


        :return: The entity_ids of this BTModelTessellationParams.  # noqa: E501
        :rtype: list[str]
        """
        return self._entity_ids

    @entity_ids.setter
    def entity_ids(self, entity_ids):
        """Sets the entity_ids of this BTModelTessellationParams.


        :param entity_ids: The entity_ids of this BTModelTessellationParams.  # noqa: E501
        :type: list[str]
        """

        self._entity_ids = entity_ids

    @property
    def output_error_faces(self):
        """Gets the output_error_faces of this BTModelTessellationParams.  # noqa: E501


        :return: The output_error_faces of this BTModelTessellationParams.  # noqa: E501
        :rtype: bool
        """
        return self._output_error_faces

    @output_error_faces.setter
    def output_error_faces(self, output_error_faces):
        """Sets the output_error_faces of this BTModelTessellationParams.


        :param output_error_faces: The output_error_faces of this BTModelTessellationParams.  # noqa: E501
        :type: bool
        """

        self._output_error_faces = output_error_faces

    @property
    def part_id(self):
        """Gets the part_id of this BTModelTessellationParams.  # noqa: E501


        :return: The part_id of this BTModelTessellationParams.  # noqa: E501
        :rtype: str
        """
        return self._part_id

    @part_id.setter
    def part_id(self, part_id):
        """Sets the part_id of this BTModelTessellationParams.


        :param part_id: The part_id of this BTModelTessellationParams.  # noqa: E501
        :type: str
        """

        self._part_id = part_id

    @property
    def document_id(self):
        """Gets the document_id of this BTModelTessellationParams.  # noqa: E501


        :return: The document_id of this BTModelTessellationParams.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTModelTessellationParams.


        :param document_id: The document_id of this BTModelTessellationParams.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def element_microversion_id(self):
        """Gets the element_microversion_id of this BTModelTessellationParams.  # noqa: E501


        :return: The element_microversion_id of this BTModelTessellationParams.  # noqa: E501
        :rtype: str
        """
        return self._element_microversion_id

    @element_microversion_id.setter
    def element_microversion_id(self, element_microversion_id):
        """Sets the element_microversion_id of this BTModelTessellationParams.


        :param element_microversion_id: The element_microversion_id of this BTModelTessellationParams.  # noqa: E501
        :type: str
        """

        self._element_microversion_id = element_microversion_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTModelTessellationParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDBViewerConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'query_field_labels': 'dict(str, str)',
        'collection_configs': 'list[BTDBViewerCollectionConfig]',
        'created_by': 'str',
        'created_at': 'datetime',
        'modified_by': 'str',
        'modified_at': 'datetime',
        'new': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'query_field_labels': 'queryFieldLabels',
        'collection_configs': 'collectionConfigs',
        'created_by': 'createdBy',
        'created_at': 'createdAt',
        'modified_by': 'modifiedBy',
        'modified_at': 'modifiedAt',
        'new': 'new'
    }

    def __init__(self, id=None, query_field_labels=None, collection_configs=None, created_by=None, created_at=None, modified_by=None, modified_at=None, new=None):  # noqa: E501
        """BTDBViewerConfig - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._query_field_labels = None
        self._collection_configs = None
        self._created_by = None
        self._created_at = None
        self._modified_by = None
        self._modified_at = None
        self._new = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if query_field_labels is not None:
            self.query_field_labels = query_field_labels
        if collection_configs is not None:
            self.collection_configs = collection_configs
        if created_by is not None:
            self.created_by = created_by
        if created_at is not None:
            self.created_at = created_at
        if modified_by is not None:
            self.modified_by = modified_by
        if modified_at is not None:
            self.modified_at = modified_at
        if new is not None:
            self.new = new

    @property
    def id(self):
        """Gets the id of this BTDBViewerConfig.  # noqa: E501


        :return: The id of this BTDBViewerConfig.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTDBViewerConfig.


        :param id: The id of this BTDBViewerConfig.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def query_field_labels(self):
        """Gets the query_field_labels of this BTDBViewerConfig.  # noqa: E501


        :return: The query_field_labels of this BTDBViewerConfig.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._query_field_labels

    @query_field_labels.setter
    def query_field_labels(self, query_field_labels):
        """Sets the query_field_labels of this BTDBViewerConfig.


        :param query_field_labels: The query_field_labels of this BTDBViewerConfig.  # noqa: E501
        :type: dict(str, str)
        """

        self._query_field_labels = query_field_labels

    @property
    def collection_configs(self):
        """Gets the collection_configs of this BTDBViewerConfig.  # noqa: E501


        :return: The collection_configs of this BTDBViewerConfig.  # noqa: E501
        :rtype: list[BTDBViewerCollectionConfig]
        """
        return self._collection_configs

    @collection_configs.setter
    def collection_configs(self, collection_configs):
        """Sets the collection_configs of this BTDBViewerConfig.


        :param collection_configs: The collection_configs of this BTDBViewerConfig.  # noqa: E501
        :type: list[BTDBViewerCollectionConfig]
        """

        self._collection_configs = collection_configs

    @property
    def created_by(self):
        """Gets the created_by of this BTDBViewerConfig.  # noqa: E501


        :return: The created_by of this BTDBViewerConfig.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this BTDBViewerConfig.


        :param created_by: The created_by of this BTDBViewerConfig.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_at(self):
        """Gets the created_at of this BTDBViewerConfig.  # noqa: E501


        :return: The created_at of this BTDBViewerConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BTDBViewerConfig.


        :param created_at: The created_at of this BTDBViewerConfig.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def modified_by(self):
        """Gets the modified_by of this BTDBViewerConfig.  # noqa: E501


        :return: The modified_by of this BTDBViewerConfig.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this BTDBViewerConfig.


        :param modified_by: The modified_by of this BTDBViewerConfig.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def modified_at(self):
        """Gets the modified_at of this BTDBViewerConfig.  # noqa: E501


        :return: The modified_at of this BTDBViewerConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this BTDBViewerConfig.


        :param modified_at: The modified_at of this BTDBViewerConfig.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def new(self):
        """Gets the new of this BTDBViewerConfig.  # noqa: E501


        :return: The new of this BTDBViewerConfig.  # noqa: E501
        :rtype: bool
        """
        return self._new

    @new.setter
    def new(self, new):
        """Sets the new of this BTDBViewerConfig.


        :param new: The new of this BTDBViewerConfig.  # noqa: E501
        :type: bool
        """

        self._new = new

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDBViewerConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAdminRolePermissionParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'method': 'str',
        'allowed': 'bool',
        '_resource_path': 'str',
        'resource_label': 'str'
    }

    attribute_map = {
        'method': 'method',
        'allowed': 'allowed',
        '_resource_path': 'resourcePath',
        'resource_label': 'resourceLabel'
    }

    def __init__(self, method=None, allowed=None, _resource_path=None, resource_label=None):  # noqa: E501
        """BTAdminRolePermissionParams - a model defined in OpenAPI"""  # noqa: E501

        self._method = None
        self._allowed = None
        self.__resource_path = None
        self._resource_label = None
        self.discriminator = None

        if method is not None:
            self.method = method
        if allowed is not None:
            self.allowed = allowed
        if _resource_path is not None:
            self._resource_path = _resource_path
        if resource_label is not None:
            self.resource_label = resource_label

    @property
    def method(self):
        """Gets the method of this BTAdminRolePermissionParams.  # noqa: E501


        :return: The method of this BTAdminRolePermissionParams.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this BTAdminRolePermissionParams.


        :param method: The method of this BTAdminRolePermissionParams.  # noqa: E501
        :type: str
        """

        self._method = method

    @property
    def allowed(self):
        """Gets the allowed of this BTAdminRolePermissionParams.  # noqa: E501


        :return: The allowed of this BTAdminRolePermissionParams.  # noqa: E501
        :rtype: bool
        """
        return self._allowed

    @allowed.setter
    def allowed(self, allowed):
        """Sets the allowed of this BTAdminRolePermissionParams.


        :param allowed: The allowed of this BTAdminRolePermissionParams.  # noqa: E501
        :type: bool
        """

        self._allowed = allowed

    @property
    def _resource_path(self):
        """Gets the _resource_path of this BTAdminRolePermissionParams.  # noqa: E501


        :return: The _resource_path of this BTAdminRolePermissionParams.  # noqa: E501
        :rtype: str
        """
        return self.__resource_path

    @_resource_path.setter
    def _resource_path(self, _resource_path):
        """Sets the _resource_path of this BTAdminRolePermissionParams.


        :param _resource_path: The _resource_path of this BTAdminRolePermissionParams.  # noqa: E501
        :type: str
        """

        self.__resource_path = _resource_path

    @property
    def resource_label(self):
        """Gets the resource_label of this BTAdminRolePermissionParams.  # noqa: E501


        :return: The resource_label of this BTAdminRolePermissionParams.  # noqa: E501
        :rtype: str
        """
        return self._resource_label

    @resource_label.setter
    def resource_label(self, resource_label):
        """Sets the resource_label of this BTAdminRolePermissionParams.


        :param resource_label: The resource_label of this BTAdminRolePermissionParams.  # noqa: E501
        :type: str
        """

        self._resource_label = resource_label

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAdminRolePermissionParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
